/* include/plib_config.hh.  Generated automatically by configure.  */
/* include/plib_config.hh.in.  Generated automatically from configure.in by autoheader.  */

/* Define if the X Window System is missing or not being used.  */
/* #undef X_DISPLAY_MISSING */

// define if you want to use exception handling
#define USE_EXCEPTION 1

// define if you want verbose exception handling
/* #undef VERBOSE_EXCEPTION */

// define if you have the ISO C++ friend declaration style
#define HAVE_ISO_FRIEND_DECL 1

// define if you can handle the template of template class
#define HAVE_TEMPLATE_OF_TEMPLATE 1

// define if you can use -fno-implicit-template
#define NO_IMPLICIT_TEMPLATES 1

// define if you can use -frepo
/* #undef INCLUDE_TEMPLATE_SOURCE */

// define if you want Image Magick 
/* #undef WITH_IMAGE_MAGICK */

// define if you want to do range validity checking
// and also other debugging functions
#define DEBUG_PLIB 1

// Define if you want the matrix to be in column order rather than row order.
// Column ordering is used by fortran and OpenGL.
/* #undef COLUMN_ORDER */

// the name of the package
#define PACKAGE 1 

// the version of the package
#define VERSION 1 

// if the C++ compiler supports namespaces
#define HAVE_NAMESPACE 1

// Specify if OpenGL is present on this system
/* #undef WITH_OPENGL */ 

// Specify if you are using Solaris with egcs
/* #undef USING_GNU_SOLARIS */

// Specify if you are using DEC Alpha with egcs
/* #undef USING_GNU_DECALPHA */

// Specify if you are using Linux (assumed with egcs)
/* #undef USING_LINUX */

/* Name of package */
#define PACKAGE 1

/* Version number of package */
#define VERSION 1

